# geopak


[![image](https://img.shields.io/pypi/v/geopak.svg)](https://pypi.python.org/pypi/geopak)
[![image](https://img.shields.io/conda/vn/conda-forge/geopak.svg)](https://anaconda.org/conda-forge/geopak)


**python package demo for geodpatial analysis**


-   Free software: MIT License
-   Documentation: https://Tandoh004.github.io/geopak
    

## Features

-   TODO
